pub struct ChunkDependencies {
dependency_by_radius: [Option<ChunkStatus>; 16],
len: usize,
radius_by_dependency: [usize; 12],
}Expand description
A collection of chunk dependencies (const-compatible).
Fields
dependency_by_radius: [Option<ChunkStatus>; 16]len: usizeradius_by_dependency: [usize; 12]Implementations
Sourceimpl ChunkDependencies
impl ChunkDependencies
Sourceconst fn from_requirements(
reqs: &[(ChunkStatus, usize)],
parent_status: Option<ChunkStatus>,
) -> Self
const fn from_requirements( reqs: &[(ChunkStatus, usize)], parent_status: Option<ChunkStatus>, ) -> Self
Creates dependencies from requirements and optional parent status.
Sourceconst fn build_radius_lookup(
deps: &[Option<ChunkStatus>; 16],
len: usize,
) -> [usize; 12]
const fn build_radius_lookup( deps: &[Option<ChunkStatus>; 16], len: usize, ) -> [usize; 12]
Builds the radius lookup table from dependency array.
Sourceconst fn accumulate(
&self,
parent_accumulated: &Self,
parent_status: ChunkStatus,
) -> Self
const fn accumulate( &self, parent_accumulated: &Self, parent_status: ChunkStatus, ) -> Self
Computes accumulated dependencies by merging with parent’s accumulated dependencies.
Sourcepub const fn get_radius_of(&self, status: ChunkStatus) -> usize
pub const fn get_radius_of(&self, status: ChunkStatus) -> usize
Gets the radius of the dependencies for the given status.
Panics
Panics if the status index is out of bounds.
Sourcepub const fn get_radius(&self) -> usize
pub const fn get_radius(&self) -> usize
Gets the radius of the dependencies.
Sourcepub const fn get(&self, distance: usize) -> Option<ChunkStatus>
pub const fn get(&self, distance: usize) -> Option<ChunkStatus>
Gets the dependency status at the given distance.